@@ -52,7 +52,7 @@ class Forecast:
     """
 
     _MAX_INIT_TIME_PAST_FOR_API_H = 36
-    _MAX_point_FOR_API = 25
+    _MAX_POINT_FOR_API = 1000
 
     def __init__(self, client: JuaClient, model: Models):
         """Initialize forecast access for a specific model.
@@ -237,7 +237,11 @@ class Forecast:
                 model=self._model,
             )
 
-        logger.warning("Large query, this might take some time.")
+        if not lazy_load:
+            logger.warning(
+                "Query might produce a large amount of data and might take some time."
+            )
+
         prediction_timedelta = self._get_prediction_timedelta_for_adapter(
             min_lead_time=min_lead_time,
             max_lead_time=max_lead_time,
@@ -500,7 +504,7 @@ class Forecast:
 
         Constraints include:
         - Forecast age (must be recent, less than 36 hours)
-        - Number of points (limited to _MAX_point_FOR_API)
+        - Number of points (limited to _MAX_POINT_FOR_API)
         - Query structure (slices not supported)
         - Lead time structure (complex lead time slicing not supported)
 
@@ -551,7 +555,7 @@ class Forecast:
         if not self._is_latest_init_time(init_time) and len(points) > 1:
             return False
 
-        if len(points) > self._MAX_point_FOR_API:
+        if len(points) > self._MAX_POINT_FOR_API:
             return False
 
         if prediction_timedelta is not None:
